@@ -37,7 +37,6 @@ namespace torali {
   struct AsmConfig {
     bool hasDumpFile;
     bool hasVcfFile;
-    bool svtcmd;
     uint16_t minMapQual;
     uint16_t minGenoQual;
     uint32_t minClip;
@@ -419,7 +418,10 @@ namespace torali {
    }
 
    // SV types to compute?
-   _svTypesToCompute(c, svtype, vm.count("svtype"));
+   if (!_svTypesToCompute(c, svtype)) {
+     std::cerr << "Please specify a valid SV type, i.e., -t INV or -t DEL,INV without spaces." << std::endl;
+     return 1;
+   }
 
    // Dump reads
    if (vm.count("dump")) c.hasDumpFile = true;
