@@ -9,7 +9,6 @@
 #include <boost/iostreams/filtering_stream.hpp>
 #include <boost/iostreams/filter/zlib.hpp>
 #include <boost/iostreams/filter/gzip.hpp>
-#include <boost/progress.hpp>
 
 #include <htslib/sam.h>
 
@@ -25,10 +24,12 @@ namespace torali {
     int32_t bppos;
     int32_t svt;
     uint32_t id;
+    int32_t chr2;
+    int32_t otherBppos;
 
-    SpanPoint() : bppos(0), svt(0), id(0) {}
-    explicit SpanPoint(int32_t bp) : bppos(bp), svt(0), id(0) {}
-    SpanPoint(int32_t bp, int32_t s, uint32_t identifier) : bppos(bp), svt(s), id(identifier) {}
+    SpanPoint() : bppos(0), svt(0), id(0), chr2(0), otherBppos(0) {}
+    explicit SpanPoint(int32_t const bp) : bppos(bp), svt(0), id(0), chr2(0), otherBppos(0) {}
+    SpanPoint(int32_t const bp, int32_t const s, uint32_t const identifier, int32_t const tid, int32_t const obp) : bppos(bp), svt(s), id(identifier), chr2(tid), otherBppos(obp) {}
   };
   
   struct BpRegion {
@@ -54,26 +55,14 @@ namespace torali {
   };
   
   struct SpanningCount {
-    int32_t refh1;
-    int32_t refh2;
-    int32_t alth1;
-    int32_t alth2;
     std::vector<uint8_t> ref;
     std::vector<uint8_t> alt;
-
-    SpanningCount() : refh1(0), refh2(0), alth1(0), alth2(0) {}
   };
 
   
   struct JunctionCount {
-    int32_t refh1;
-    int32_t refh2;
-    int32_t alth1;
-    int32_t alth2;
     std::vector<uint8_t> ref;
     std::vector<uint8_t> alt;
-
-    JunctionCount() : refh1(0), refh2(0), alth1(0), alth2(0) {}
   };
 
   template<typename TAlign, typename TQualities>
@@ -149,13 +138,11 @@ namespace torali {
 
     // Preprocess REF and ALT
     boost::posix_time::ptime noww = boost::posix_time::second_clock::local_time();
-    std::cout << '[' << boost::posix_time::to_simple_string(noww) << "] " << "Generate REF and ALT probes" << std::endl;
-    boost::progress_display show_progresss( hdr->n_targets );
+    std::cerr << '[' << boost::posix_time::to_simple_string(noww) << "] " << "Generate REF and ALT probes" << std::endl;
 
     TProbes refProbes(svs.size());
     faidx_t* fai = fai_load(c.genome.string().c_str());
     for(int32_t refIndex=0; refIndex < (int32_t) hdr->n_targets; ++refIndex) {
-      ++show_progresss;
       char* seq = NULL;
 
       // Iterate all structural variants
@@ -180,7 +167,7 @@ namespace torali {
 	if ((itSV->chr != itSV->chr2) && (itSV->chr2 == refIndex)) {
 	  Breakpoint bp(*itSV);
 	  _initBreakpoint(hdr, bp, (int32_t) itSV->consensus.size(), itSV->svt);
-	  refProbes[itSV->id] = _getSVRef(seq, bp, refIndex, itSV->svt);
+	  refProbes[itSV->id] = _getSVRef(c, seq, bp, refIndex, itSV->svt);
 	}
 	if (itSV->chr == refIndex) {
 	  Breakpoint bp(*itSV);
@@ -189,7 +176,7 @@ namespace torali {
 	    int32_t bufferSpace = std::max((int32_t) ((itSV->consensus.size() - itSV->insLen) / 3), c.minimumFlankSize);
 	    _initBreakpoint(hdr, bp, bufferSpace, itSV->svt);
 	  } else _initBreakpoint(hdr, bp, (int32_t) itSV->consensus.size(), itSV->svt);
-	  std::string svRefStr = _getSVRef(seq, bp, refIndex, itSV->svt);
+	  std::string svRefStr = _getSVRef(c, seq, bp, refIndex, itSV->svt);
 	  
 	  // Find breakpoint to reference
 	  typedef boost::multi_array<char, 2> TAlign;
@@ -306,8 +293,7 @@ namespace torali {
     
     // Iterate all samples
     boost::posix_time::ptime now = boost::posix_time::second_clock::local_time();
-    std::cout << '[' << boost::posix_time::to_simple_string(now) << "] " << "SV annotation" << std::endl;
-    boost::progress_display show_progress( totalTarget );
+    std::cerr << '[' << boost::posix_time::to_simple_string(now) << "] " << "SV annotation" << std::endl;
 
     
     typedef std::vector<uint32_t> TRefAlignCount;
@@ -339,7 +325,6 @@ namespace torali {
       
       // Iterate chromosomes
       for(int32_t refIndex=0; refIndex < (int32_t) hdr[file_c]->n_targets; ++refIndex) {
-	++show_progress;
       
 	// Any SV breakpoints on this chromosome?
 	if (!svOnChr[refIndex]) continue;
@@ -380,11 +365,11 @@ namespace torali {
 	  if (itSV->peSupport == 0) continue;
 	  if ((itSV->chr == refIndex) && (itSV->svStart < (int32_t) hdr[file_c]->target_len[refIndex])) {
 	    spanBp[itSV->svStart] = 1;
-	    spanPoint.push_back(SpanPoint(itSV->svStart, itSV->svt, itSV->id));
+	    spanPoint.push_back(SpanPoint(itSV->svStart, itSV->svt, itSV->id, itSV->chr2, itSV->svEnd));
 	  }
 	  if ((itSV->chr2 == refIndex) && (itSV->svEnd < (int32_t) hdr[file_c]->target_len[refIndex])) {
 	    spanBp[itSV->svEnd] = 1;
-	    spanPoint.push_back(SpanPoint(itSV->svEnd, itSV->svt, itSV->id));
+	    spanPoint.push_back(SpanPoint(itSV->svEnd, itSV->svt, itSV->id, itSV->chr, itSV->svStart));
 	  }
 	}
 	std::sort(spanPoint.begin(), spanPoint.end(), SortBp<SpanPoint>());
@@ -493,16 +478,9 @@ namespace torali {
 			for (int i = 0; i < rec->core.l_qseq; ++i) quality[i] = qualptr[i];
 			uint32_t rq = _getAlignmentQual(alignRef, quality);
 			if (rq >= c.minGenoQual) {
-			  uint8_t* hpptr = bam_aux_get(rec, "HP");
 #pragma omp critical
 			  {
 			    countMap[file_c][itBp->id].ref.push_back((uint8_t) std::min(rq, (uint32_t) rec->core.qual));
-			    if (hpptr) {
-			      c.isHaplotagged = true;
-			      int hap = bam_aux2i(hpptr);
-			      if (hap == 1) ++countMap[file_c][itBp->id].refh1;
-			      else ++countMap[file_c][itBp->id].refh2;
-			    }
 			  }
 			}
 		      }
@@ -513,7 +491,6 @@ namespace torali {
 		      for (int i = 0; i < rec->core.l_qseq; ++i) quality[i] = qualptr[i];
 		      uint32_t aq = _getAlignmentQual(alignAlt, quality);
 		      if (aq >= c.minGenoQual) {
-			uint8_t* hpptr = bam_aux_get(rec, "HP");
 #pragma omp critical
 			{
 			  if (c.hasDumpFile) {
@@ -524,12 +501,6 @@ namespace torali {
 			    dumpOut << svid << "\t" << c.files[file_c].string() << "\t" << bam_get_qname(rec) << "\t" << hdr[file_c]->target_name[rec->core.tid] << "\t" << rec->core.pos << "\t" << hdr[file_c]->target_name[rec->core.mtid] << "\t" << rec->core.mpos << "\t" << (int32_t) rec->core.qual << "\tSR" << std::endl;
 			  }
 			  countMap[file_c][itBp->id].alt.push_back((uint8_t) std::min(aq, (uint32_t) rec->core.qual));
-			  if (hpptr) {
-			    c.isHaplotagged = true;
-			    int hap = bam_aux2i(hpptr);
-			    if (hap == 1) ++countMap[file_c][itBp->id].alth1;
-			    else ++countMap[file_c][itBp->id].alth2;
-			  }
 			}
 		      }
 		    }
@@ -597,7 +568,7 @@ namespace torali {
 	    if (sampleLib[file_c].median == 0) continue; // Single-end library or non-valid library
 
 	    // Normal spanning pair
-	    if ((!pairClip) && (getSVType(rec->core) == 2) && (outerISize >= sampleLib[file_c].minNormalISize) && (outerISize <= sampleLib[file_c].maxNormalISize) && (rec->core.tid==rec->core.mtid)) {
+	    if ((!pairClip) && (getSVType(rec) == 2) && (outerISize >= sampleLib[file_c].minNormalISize) && (outerISize <= sampleLib[file_c].maxNormalISize) && (rec->core.tid==rec->core.mtid)) {
 	      // Take X% of the outerisize as the spanned interval
 	      int32_t spanlen = 0.8 * outerISize;
 	      int32_t pbegin = std::min((int32_t) rec->core.pos, (int32_t) rec->core.mpos);
@@ -615,16 +586,9 @@ namespace torali {
 		for(; ((itSpan != spanPoint.end()) && (st + spanlen >= itSpan->bppos)); ++itSpan) {
 		  // Account for reference bias
 		  if (++refAlignedSpanCount[file_c][itSpan->id] % 2) {
-		    uint8_t* hpptr = bam_aux_get(rec, "HP");
 #pragma omp critical
 		    {
 		      spanMap[file_c][itSpan->id].ref.push_back(pairQuality);
-		      if (hpptr) {
-			c.isHaplotagged = true;
-			int hap = bam_aux2i(hpptr);
-			if (hap == 1) ++spanMap[file_c][itSpan->id].refh1;
-			else ++spanMap[file_c][itSpan->id].refh2;
-		      }
 		    }
 		  }
 		}
@@ -632,7 +596,7 @@ namespace torali {
 	    }
 	    
 	    // Abnormal spanning coverage
-	    if ((getSVType(rec->core) != 2) || (outerISize < sampleLib[file_c].minNormalISize) || (outerISize > sampleLib[file_c].maxNormalISize) || (rec->core.tid!=rec->core.mtid)) {
+	    if ((getSVType(rec) != 2) || (outerISize < sampleLib[file_c].minNormalISize) || (outerISize > sampleLib[file_c].maxNormalISize) || (rec->core.tid!=rec->core.mtid)) {
 	      // SV type
 	      int32_t svt = _isizeMappingPos(rec, sampleLib[file_c].maxISizeCutoff);
 	      if (svt == -1) continue;
@@ -656,22 +620,20 @@ namespace torali {
 		typename TSpanPoint::iterator itSpan = std::lower_bound(spanPoint.begin(), spanPoint.end(), SpanPoint(pbegin), SortBp<SpanPoint>());
 		for(; ((itSpan != spanPoint.end()) && (pend >= itSpan->bppos)); ++itSpan) {
 		  if (svt == itSpan->svt) {
-		    uint8_t* hpptr = bam_aux_get(rec, "HP");
+		    // Make sure, mate is correct
+		    if (rec->core.mtid == itSpan->chr2) {
+		      if (std::abs((int32_t) rec->core.mpos - itSpan->otherBppos) < sampleLib[file_c].maxNormalISize) {
 #pragma omp critical
-		    {
-		      if (c.hasDumpFile) {
-			std::string svid(_addID(itSpan->svt));
-			std::string padNumber = boost::lexical_cast<std::string>(itSpan->id);
-			padNumber.insert(padNumber.begin(), 8 - padNumber.length(), '0');
-			svid += padNumber;
-			dumpOut << svid << "\t" << c.files[file_c].string() << "\t" << bam_get_qname(rec) << "\t" << hdr[file_c]->target_name[rec->core.tid] << "\t" << rec->core.pos << "\t" << hdr[file_c]->target_name[rec->core.mtid] << "\t" << rec->core.mpos << "\t" << (int32_t) rec->core.qual << "\tPE" << std::endl;
-		      }
-		      spanMap[file_c][itSpan->id].alt.push_back(pairQuality);
-		      if (hpptr) {
-			c.isHaplotagged = true;
-			int hap = bam_aux2i(hpptr);
-			if (hap == 1) ++spanMap[file_c][itSpan->id].alth1;
-			else ++spanMap[file_c][itSpan->id].alth2;
+			{
+			  if (c.hasDumpFile) {
+			    std::string svid(_addID(itSpan->svt));
+			    std::string padNumber = boost::lexical_cast<std::string>(itSpan->id);
+			    padNumber.insert(padNumber.begin(), 8 - padNumber.length(), '0');
+			    svid += padNumber;
+			    dumpOut << svid << "\t" << c.files[file_c].string() << "\t" << bam_get_qname(rec) << "\t" << hdr[file_c]->target_name[rec->core.tid] << "\t" << rec->core.pos << "\t" << hdr[file_c]->target_name[rec->core.mtid] << "\t" << rec->core.mpos << "\t" << (int32_t) rec->core.qual << "\tPE" << std::endl;
+			  }
+			  spanMap[file_c][itSpan->id].alt.push_back(pairQuality);
+			}
 		      }
 		    }
 		  }
