@@ -163,8 +163,7 @@ namespace torali {
 
     // Calculate coverage
     typedef boost::multi_array<bool, 2> TFlag;
-    TFlag fl;
-    fl.resize(boost::extents[align.shape()[0]][align.shape()[1]]);
+    TFlag fl(boost::extents[align.shape()[0]][align.shape()[1]]);
     typedef std::vector<int> TCoverage;
     TCoverage cov;
     cov.resize(align.shape()[1], 0);
