@@ -2,6 +2,7 @@
 #define SPLIT_H
 
 #include <iostream>
+#include "edlib.h"
 #include "gotoh.h"
 #include "needle.h"
 
@@ -121,10 +122,9 @@ namespace torali
     return false;
   }
 
-  // Deletions
-  template<typename TSeq, typename TSVRecord, typename TRef>
+  template<typename TConfig, typename TSeq, typename TSVRecord, typename TRef>
   inline std::string
-  _getSVRef(TSeq const* const ref, TSVRecord const& svRec, TRef const refIndex, int32_t const svt) {
+  _getSVRef(TConfig const& c, TSeq const* const ref, TSVRecord const& svRec, TRef const refIndex, int32_t const svt) {
     if (_translocation(svt)) {
       uint8_t ct = _getSpanOrientation(svt);
       if (svRec.chr==refIndex) {
@@ -168,7 +168,7 @@ namespace torali
       }
     } else {
       if (svt == 2) {
-	if (svRec.svEnd - svRec.svStart <= DELLY_CHOP_REFSIZE) return boost::to_upper_copy(std::string(ref + svRec.svStartBeg, ref + svRec.svEndEnd));
+	if (svRec.svEnd - svRec.svStart <= c.indelsize) return boost::to_upper_copy(std::string(ref + svRec.svStartBeg, ref + svRec.svEndEnd));
 	else return boost::to_upper_copy(std::string(ref + svRec.svStartBeg, ref + svRec.svStartEnd)) + boost::to_upper_copy(std::string(ref + svRec.svEndBeg, ref + svRec.svEndEnd));
       } else if (svt == 4) {
 	return boost::to_upper_copy(std::string(ref + svRec.svStartBeg, ref + svRec.svEndEnd));
@@ -212,9 +212,9 @@ namespace torali
   }
 
 
-  template<typename TString, typename TSvRecord, typename TAlignDescriptor, typename TPosition>
+  template<typename TConfig, typename TString, typename TSvRecord, typename TAlignDescriptor, typename TPosition>
   inline bool
-  _coordTransform(TString const& ref, TSvRecord const& sv, TAlignDescriptor const& ad, TPosition& finalGapStart, TPosition& finalGapEnd, int32_t svt) {
+  _coordTransform(TConfig const& c, TString const& ref, TSvRecord const& sv, TAlignDescriptor const& ad, TPosition& finalGapStart, TPosition& finalGapEnd, int32_t svt) {
     if (_translocation(svt)) {
       uint8_t ct = _getSpanOrientation(svt);
       if (ct == 0) {
@@ -241,7 +241,7 @@ namespace torali
       return true;
     } else {
       if (svt == 2) {
-	if (sv.svEnd - sv.svStart > DELLY_CHOP_REFSIZE) {
+	if (sv.svEnd - sv.svStart > c.indelsize) {
 	  int32_t annealed = sv.svStartEnd - sv.svStartBeg;
 	  if ((ad.rStart >= annealed) || (ad.rEnd < annealed)) return false;
 	  finalGapStart = sv.svStartBeg + ad.rStart;
@@ -429,7 +429,7 @@ namespace torali
 
   template<typename TConfig>
   inline bool
-  alignConsensus(TConfig const& c, bam_hdr_t* hdr, char const* seq, char const* sndSeq, StructuralVariantRecord& sv) {
+  alignConsensus(TConfig const& c, bam_hdr_t* hdr, char const* seq, char const* sndSeq, StructuralVariantRecord& sv, bool const realign) {
     if ( (int32_t) sv.consensus.size() < (2 * c.minimumFlankSize + sv.insLen)) return false;
     
     // Get reference slice
@@ -438,9 +438,21 @@ namespace torali
       int32_t bufferSpace = std::max((int32_t) ((sv.consensus.size() - sv.insLen) / 3), c.minimumFlankSize);
       _initBreakpoint(hdr, bp, bufferSpace, sv.svt);
     } else _initBreakpoint(hdr, bp, sv.consensus.size(), sv.svt);
-    if (bp.chr != bp.chr2) bp.part1 = _getSVRef(sndSeq, bp, bp.chr2, sv.svt);
-    std::string svRefStr = _getSVRef(seq, bp, bp.chr, sv.svt);
-
+    if (bp.chr != bp.chr2) bp.part1 = _getSVRef(c, sndSeq, bp, bp.chr2, sv.svt);
+    std::string svRefStr = _getSVRef(c, seq, bp, bp.chr, sv.svt);
+    
+    // Realign?
+    if (realign) {
+      std::string revc = sv.consensus;
+      reverseComplement(revc);
+      EdlibAlignResult alignFwd = edlibAlign(sv.consensus.c_str(), sv.consensus.size(), svRefStr.c_str(), svRefStr.size(), edlibNewAlignConfig(-1, EDLIB_MODE_NW, EDLIB_TASK_DISTANCE, NULL, 0));
+      EdlibAlignResult alignRev = edlibAlign(revc.c_str(), revc.size(), svRefStr.c_str(), svRefStr.size(), edlibNewAlignConfig(-1, EDLIB_MODE_NW, EDLIB_TASK_DISTANCE, NULL, 0));
+      if (alignRev.editDistance < alignFwd.editDistance) sv.consensus = revc;
+      edlibFreeAlignResult(alignFwd);
+      edlibFreeAlignResult(alignRev);
+    }
+    
+    
     // Consensus to reference alignment
     typedef boost::multi_array<char, 2> TAlign;
     TAlign align;
@@ -458,11 +470,11 @@ namespace torali
     // Check breakpoint
     AlignDescriptor ad;
     if (!_findSplit(c, sv.consensus, svRefStr, align, ad, sv.svt)) return false;
-
+    
     // Get the start and end of the structural variant
     unsigned int finalGapStart = 0;
     unsigned int finalGapEnd = 0;
-    if (!_coordTransform(svRefStr, bp, ad, finalGapStart, finalGapEnd, sv.svt)) return false;
+    if (!_coordTransform(c, svRefStr, bp, ad, finalGapStart, finalGapEnd, sv.svt)) return false;
     
     sv.precise=true;
     sv.svStart=finalGapStart;
@@ -476,34 +488,14 @@ namespace torali
     sv.ciendlow = -ci_wiggle;
     sv.ciendhigh = ci_wiggle;
 
-    if (c.islr) {
-      // Set alleles
-      sv.alleles = _addAlleles(boost::to_upper_copy(std::string(seq + sv.svStart - 1, seq + sv.svStart)), std::string(hdr->target_name[sv.chr2]), sv, sv.svt);
-    
-      // Get exact alleles for INS and DEL                                                                         
-      if ((sv.svt == 2) || (sv.svt == 4)) {
-	std::string refVCF;
-	std::string altVCF;
-	int32_t cpos = 0;
-	bool inSV = false;
-	for(uint32_t j = 0; j<align.shape()[1]; ++j) {
-	  if (align[0][j] != '-') {
-	    ++cpos;
-	    if (cpos == ad.cStart) inSV = true;
-	    else if (cpos == ad.cEnd) inSV = false;
-	  }
-	  if (inSV) {
-	    if (align[0][j] != '-') altVCF += align[0][j];
-	    if (align[1][j] != '-') refVCF += align[1][j];
-	  }
-	}
-	sv.alleles = _addAlleles(refVCF, altVCF);
-      }
-    }
-
     return true;
   }
 
+  template<typename TConfig>
+  inline bool
+  alignConsensus(TConfig const& c, bam_hdr_t* hdr, char const* seq, char const* sndSeq, StructuralVariantRecord& sv) {
+    return alignConsensus(c, hdr, seq, sndSeq, sv, false);
+  }
 
 
 }
